==> tuo-visual-document-react-1.0.2.tgz: package/src/index.tsx <==
import React, {useEffect, useState} from 'react'
import { TuoAsyn } from 'tuo-asyn2'
import useAsyncEffect from 'use-async-effect'
import {Document} from 'tuo-document'
import View3D from './view3d'
import styles from './styles/index.module.css'
import ViewToolBar from './viewToolBar'

type TuoVisualReactProps = {
  docResourceUrl: string, // 加载文档入口文件.TuoDocument文件
  docUpdateUrl: string, // 用于文件实体发生更新时同步数据的url地址
  docBaseUrl: string, // 用于加载.bin文件时参考的baseUrl
  asyn: any,   // TuoAsyn2的实例
  docRef: {current: any},
  doc: any     //如果此属性不为undefined,则前面的url失效
}

export default function TuoVisualReact({docResourceUrl, docUpdateUrl, docBaseUrl, asyn, docRef, doc}){
  const [localDoc, setLocalDoc] = useState() 
  const [hasFocus, setHasFocus] = useState(false)

  if(doc){
    if(docRef)
      docRef.current = doc

    setLocalDoc((previous) => {
      if(previous)
        previous.dispose()
      return undefined
    })
    return <View3D doc = {doc}/>
  } 

  let theAsyn = asyn
  if(!theAsyn)
    theAsyn = new TuoAsyn({
      fetchType: 'public'
    })

  useAsyncEffect(async () => {
    let docConfig = {
      asyn: theAsyn,
      baseUrl: docBaseUrl,
      updater: undefined
    }
    if(docUpdateUrl){
      docConfig.updater = {
      }
    }

    const theDoc = new Document(docConfig)

    await theDoc.loadDocument(docResourceUrl, docUpdateUrl, [])
    theDoc.callAfterComplete(async () => {
      theDoc.viewDocument.setCamera({
        // type: "Perspective",
        type: 'Orthographic',
        options: {
          near: 0.1,
          far: 10000
        }
      });

      theDoc.viewDocument.setCameraControls({
        type: 'trackball',
        options: {
          zoomSpeed: 0.1,
          rotateSpeed: 2.5,
          enableDamping: false,
          minZoom: 0.1,
          maxZoom: 1000
        }
      });

      theDoc.viewDocument.fitScene(true, false, 10000);
      theDoc.viewDocument.setViewPoint("Front");
      theDoc.setOriginState();
    })
    if(docRef)
      docRef.current = theDoc


    setLocalDoc((previous) => {
      if(previous)
        previous.dispose()
      return theDoc
    })
    return () => {
      console.log('dispose a doc')
      theDoc.dispose()
    }

  }, [])

  const onMouseOver = () => {
    setHasFocus(true)
  }

  const onMouseOut = () => {
    setHasFocus(false)
  }
  return <div
    className = {styles.container}
    onMouseOver = {onMouseOver}
    onMouseOut = {onMouseOut}
  >
    <ViewToolBar doc = {localDoc} hasFocus = {hasFocus}/>
    <View3D doc = {localDoc}></View3D>
  </div>
}

==> tuo-visual-document-react-1.0.3.tgz: package/src/index.tsx <==
import React, {useEffect, useState} from 'react'
import { TuoAsyn } from 'tuo-asyn2'
import useAsyncEffect from 'use-async-effect'
import {Document} from 'tuo-document'
import View3D from './view3d'
import styles from './styles/index.module.css'
import ViewToolBar from './viewToolBar'

type TuoVisualReactProps = {
  docResourceUrl: string, // 加载文档入口文件.TuoDocument文件
  docUpdateUrl: string, // 用于文件实体发生更新时同步数据的url地址
  docBaseUrl: string, // 用于加载.bin文件时参考的baseUrl
  asyn: any,   // TuoAsyn2的实例
  docRef: {current: any},
  doc: any,     //如果此属性不为undefined,则前面的url失效
  onFinish: () => {}
}

export default function TuoVisualReact({docResourceUrl, docUpdateUrl, docBaseUrl, asyn, docRef, doc, onFinish}){
  const [localDoc, setLocalDoc] = useState() 
  const [hasFocus, setHasFocus] = useState(false)

  if(doc){
    if(docRef)
      docRef.current = doc

    setLocalDoc((previous) => {
      if(previous)
        previous.dispose()
      return undefined
    })
    return <View3D doc = {doc}/>
  } 

  let theAsyn = asyn
  if(!theAsyn)
    theAsyn = new TuoAsyn({
      fetchType: 'public'
    })

  useAsyncEffect(async () => {
    let docConfig = {
      asyn: theAsyn,
      baseUrl: docBaseUrl,
      updater: undefined
    }
    if(docUpdateUrl){
      docConfig.updater = {
      }
    }

    const theDoc = new Document(docConfig)

    await theDoc.loadDocument(docResourceUrl, docUpdateUrl, [])
    theDoc.callAfterComplete(async () => {
      theDoc.viewDocument.setCamera({
        // type: "Perspective",
        type: 'Orthographic',
        options: {
          near: 0.1,
          far: 10000
        }
      });

      theDoc.viewDocument.setCameraControls({
        type: 'trackball',
        options: {
          zoomSpeed: 0.1,
          rotateSpeed: 2.5,
          enableDamping: false,
          minZoom: 0.1,
          maxZoom: 1000
        }
      });

      theDoc.viewDocument.fitScene(true, false, 10000);
      theDoc.viewDocument.setViewPoint("Front");
      theDoc.setOriginState();

      if(onFinish)
        onFinish()
    })
    if(docRef)
      docRef.current = theDoc


    setLocalDoc((previous) => {
      if(previous)
        previous.dispose()
      return theDoc
    })
    return () => {
      console.log('dispose a doc')
      theDoc.dispose()
    }

  }, [])

  const onMouseOver = () => {
    setHasFocus(true)
  }

  const onMouseOut = () => {
    setHasFocus(false)
  }
  return <div
    className = {styles.container}
    onMouseOver = {onMouseOver}
    onMouseOut = {onMouseOut}
  >
    <ViewToolBar doc = {localDoc} hasFocus = {hasFocus}/>
    <View3D doc = {localDoc}></View3D>
  </div>
}
